@@ -23,7 +23,7 @@ __copyright__ = "2021 - {0}, {1}".format(date.today().year, __author__)
 __email__ = "qgis@oslandia.com"
 __executable_name__ = "QGIS_DeploymentCLI.exe"
 __package_name__ = "qgis-deployment-toolbelt"
-__keywords__ = ["cli, QGIS, deployment, PyQGIS"]
+__keywords__ = ["cli, QGIS, deployment, profiles"]
 __license__ = "GNU Lesser General Public License v3.0"
 __summary__ = (
     "QGIS deployment toolbelt is a CLI (Command Line Interface) to perform "
@@ -36,7 +36,7 @@ __uri_repository__ = "https://github.com/Guts/qgis-deployment-cli/"
 __uri_tracker__ = "https://github.com/Guts/qgis-deployment-cli/issues/"
 __uri__ = __uri_repository__
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 __version_info__ = tuple(
     [
         int(num) if num.isdigit() else num
